@@ -74,3 +74,19 @@ class ObjectCreationException(MsActiveDirectoryException):
 class ObjectNotFoundException(MsActiveDirectoryException):
     def __init__(self, exception_str):
         super().__init__(exception_str)
+
+
+class PermissionDeniedException(MsActiveDirectoryException):
+    def __init__(self, exception_str):
+        super().__init__(exception_str)
+
+
+class SecurityDescriptorDecodeException(MsActiveDirectoryException):
+    def __init__(self, exception_str):
+        super().__init__(exception_str)
+
+
+class SecurityDescriptorEncodeException(MsActiveDirectoryException):
+    def __init__(self, exception_str):
+        super().__init__(exception_str)
+
